/*
 *    Example program for the Allegro library, by Shawn Hargreaves.
 *
 *    This program demonstrates the use of triple buffering. Several
 *    triangles are displayed rotating and bouncing on the screen
 *    until you press a key. Note that on some platforms you
 *    can't get real hardware triple buffering.  The Allegro code
 *    remains the same, but most likely the graphic driver will
 *    emulate it. Unfortunately, in these cases you can't expect
 *    the animation to be completely smooth and flicker free.
 */


#include <allegro.h>
#include <iostream>
#include <cmath>

#include "siatka.cpp"
#include "rycerz.cpp"
#include "myszka.cpp"


#include<string>


#define liczba_komurek_w_poziomie   150
#define liczba_komurek_w_pionie     15



volatile long speed = 0;
void increment_speed()
{
  speed++;
}
END_OF_FUNCTION(increment_speed);
LOCK_VARIABLE(speed);
LOCK_FUNCTION(increment_speed);


/* main animation control loop */
int triple_buffer(BITMAP *bufor, BITMAP *trawa)
{


}




int main(void)
{

   int w, h;
   int najmniejsza_odleglosc_miedzy_rycerzami = 40;

#ifdef ALLEGRO_DOS
   w = 320;
   h = 240;
#else
   w = 800;
   h = 600;
#endif

//-----------------------------------------------------------
// inicjacja allegro

   if (allegro_init() != 0)
      return 1;
   install_timer(); 
   install_int_ex(increment_speed, BPS_TO_TIMER(80));
   install_keyboard();
   install_mouse();

  set_color_depth(32);
  set_gfx_mode(GFX_AUTODETECT_WINDOWED,w,h,0,0);
  clear_to_color(screen, makecol(128,128,128));

   set_palette(desktop_palette);

//-----------------------------------------------------------

	BITMAP *bufor = NULL;
	bufor = create_bitmap(SCREEN_W,SCREEN_H);
	if (!bufor)
  	{
		set_gfx_mode(GFX_TEXT,0,0,0,0);
		allegro_message("Nie mogę utworzyć bufora !");
		allegro_exit();
		return 0;
	}


//-----------------------------------------------------------
// myszka

	Myszka myszka;


// ----------------------
// trawa

  BITMAP *trawa = NULL;

  trawa = load_bmp("T_rough_ripple_earth_medium/grass.bmp",default_palette);
  if (!trawa)
  {
    set_gfx_mode(GFX_TEXT,0,0,0,0);
    allegro_message("nie mogę załadować obrazka trawa !");
    allegro_exit();
    return 0;
  }

   int trawa_x = 0, trawa_y = 0;


// ----------------------
		   

	Siatka siatka_widoczna_na_ekranie;
	
	int liczba_rycerzy = 10;
	Rycerz **rycerz;
	rycerz=new Rycerz*[liczba_rycerzy];
	for(int i=0; i<liczba_rycerzy; i++)
	{
		rycerz[i]=new Rycerz(140,100+i*50,2);
	}

	
// ----------------------

     int time = 20;
     int frame = 0;

     while( !key[KEY_ESC])
     {

	    while( speed > 0)
	    {

	      speed--;

	      frame++;
	      if( frame >= 130) frame=0;
	    }

	clear_to_color(bufor, makecol(150,150,150));


		siatka_widoczna_na_ekranie.draw(bufor, trawa);

		for(int i=0; i<liczba_rycerzy; i++)
		{
			rycerz[i]->draw(bufor, time , frame, myszka.obszar_zaznaczenia_x1, myszka.obszar_zaznaczenia_y1, myszka.obszar_zaznaczenia_x2, myszka.obszar_zaznaczenia_y2);
			for(int j=0; j<liczba_rycerzy; j++)
			{
				if(i != j)
				{
					 if(sqrt(pow(abs(rycerz[i]->poz_x - rycerz[j]->poz_x), 2)+pow(abs(rycerz[i]->poz_y - rycerz[j]->poz_y), 2)) < najmniejsza_odleglosc_miedzy_rycerzami)
					 {
						 rycerz[i]->pozwolenie_na_marsz = 1;
						 
					 }
				}
			}
			
		}
		
		
		myszka.draw(bufor);

		if(myszka.mb == 1)
		{
			for(int i=0; i<liczba_rycerzy; i++)
			{
				rycerz[i]->wybrany = 0;
			}
		}
		
		if(myszka.mb == 2)
		{
			for(int i=0; i<liczba_rycerzy; i++)
			{
				rycerz[i]->nastepna_pozycja(myszka.x, myszka.y);
				
				rycerz[i]->pozwolenie_na_marsz = 0;
				for(int j=0; j<liczba_rycerzy; j++)
				{
					if(i != j)
					{
						if(sqrt(pow(abs(rycerz[i]->next_poz_x - rycerz[j]->poz_x), 2)+pow(abs(rycerz[i]->next_poz_y - rycerz[j]->poz_y), 2)) < najmniejsza_odleglosc_miedzy_rycerzami)
						{
								rycerz[i]->pozwolenie_na_marsz += 1;
						}
					}
				}
				rycerz[i]->idz(myszka.x, myszka.y);
				
			}
		}
		
		if(myszka.mb == 2)
		{
			
		}


	blit( bufor, screen, 0,0,0,0, w, h);



   clear_keybuf();


   triple_buffer(bufor, trawa);
     }

   for(int i=0; i<liczba_rycerzy; i++)
		delete rycerz[i];
	delete []rycerz;

   return 0;
}

//END_OF_MAIN()
